==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/IPBUYVENDORSUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour IPBUYVENDORSUPPLIERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="IPBUYVENDORSUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPBUYVENDORID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IPBUYVENDORSUPPLIERID_Type", propOrder = {
    "ipbuyvendorid",
    "supplierid"
})
public class IPBUYVENDORSUPPLIERID_Type {

    @XmlElement(name = "IPBUYVENDORID", required = true)
    protected IPBUYVENDORID_Type ipbuyvendorid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Obtient la valeur de la propriété ipbuyvendorid.
     * 
     * @return
     *     possible object is
     *     {@link IPBUYVENDORID_Type }
     *     
     */
    public IPBUYVENDORID_Type getIPBUYVENDORID() {
        return ipbuyvendorid;
    }

    /**
     * Définit la valeur de la propriété ipbuyvendorid.
     * 
     * @param value
     *     allowed object is
     *     {@link IPBUYVENDORID_Type }
     *     
     */
    public void setIPBUYVENDORID(IPBUYVENDORID_Type value) {
        this.ipbuyvendorid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/IPBUYVENDORSUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for IPBUYVENDORSUPPLIERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="IPBUYVENDORSUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPBUYVENDORID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IPBUYVENDORSUPPLIERID_Type", propOrder = {
    "ipbuyvendorid",
    "supplierid"
})
public class IPBUYVENDORSUPPLIERID_Type {

    @XmlElement(name = "IPBUYVENDORID", required = true)
    protected IPBUYVENDORID_Type ipbuyvendorid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;

    /**
     * Gets the value of the ipbuyvendorid property.
     * 
     * @return
     *     possible object is
     *     {@link IPBUYVENDORID_Type }
     *     
     */
    public IPBUYVENDORID_Type getIPBUYVENDORID() {
        return ipbuyvendorid;
    }

    /**
     * Sets the value of the ipbuyvendorid property.
     * 
     * @param value
     *     allowed object is
     *     {@link IPBUYVENDORID_Type }
     *     
     */
    public void setIPBUYVENDORID(IPBUYVENDORID_Type value) {
        this.ipbuyvendorid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

}
